Stan Math Library: stan/math/prim/scal/fun/log1m_inv_logit.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log1m_inv_logit.hpp File Reference
`#include <boost/math/tools/promotion.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
boost::math::tools::promote_args< T >::type | stan::math::log1m_inv_logit (const T u)
| Returns the natural logarithm of 1 minus the inverse logit of the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.